Installation
====================================

Using Pip
---------
.. code-block:: bash

   # Install all the metadata sources
   pip install 'metadata_guardian[all]'

   # Install one metadata source in the list
   pip install 'metadata_guardian[snowflake,avro,parquet,orc,aws,gcp,deltalake]'